@@ -16,8 +16,6 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.hinemosagent.dialog;
 
 import org.eclipse.swt.SWT;
-import org.eclipse.swt.events.SelectionAdapter;
-import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.graphics.Point;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
@@ -28,7 +26,7 @@ import org.eclipse.swt.widgets.Group;
 import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 
-import com.clustercontrol.bean.MonitorConstant;
+import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.ValidConstant;
 import com.clustercontrol.bean.YesNoConstant;
 import com.clustercontrol.dialog.CommonDialog;
@@ -43,15 +41,15 @@ import com.clustercontrol.monitor.run.bean.MonitorTypeConstant;
 import com.clustercontrol.monitor.run.composite.MonitorBasicScopeComposite;
 import com.clustercontrol.monitor.run.composite.MonitorBlockComposite;
 import com.clustercontrol.monitor.run.composite.MonitorRuleComposite;
-import com.clustercontrol.monitor.run.composite.TruthRunJobComposite;
 import com.clustercontrol.monitor.run.composite.TruthValueInfoComposite;
+import com.clustercontrol.notify.bean.NotifyRelationInfo;
 import com.clustercontrol.notify.composite.NotifyInfoComposite;
 import com.clustercontrol.util.Messages;
 
 /**
  * Hinemos Agent監視作成・変更ダイアログクラス<BR>
  * 
- * @version 2.2.0
+ * @version 3.0.0
  * @since 2.0.0
  */
 public class AgentCreateDialog extends CommonDialog {
@@ -91,11 +89,6 @@ public class AgentCreateDialog extends CommonDialog {
     /** 通知情報 */
     private NotifyInfoComposite notifyInfo = null;
     
-    /** ジョブ実行 */
-    private Button m_checkJobRun = null;
-    
-    /** ジョブ実行情報 */
-    private TruthRunJobComposite m_jobRun = null;
 
     /** この設定を有効にする */
     private Button confirmValid = null;
@@ -117,8 +110,8 @@ public class AgentCreateDialog extends CommonDialog {
      * 
      * @param parent
      *            親のシェルオブジェクト
-     * @param notifyId
-     *            変更する通知ID
+     * @param monitorId
+     *            変更する監視項目ID
      */
     public AgentCreateDialog(Shell parent, String monitorId) {
         super(parent);
@@ -360,46 +353,7 @@ public class AgentCreateDialog extends CommonDialog {
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		notifyInfo.setLayoutData(gridData);
-		
-		// ジョブ実行
-        this.m_checkJobRun = new Button(groupNotifyAttribute, SWT.CHECK);
-        gridData = new GridData();
-        gridData.horizontalSpan = 1;
-        gridData.horizontalAlignment = GridData.FILL;
-        gridData.grabExcessHorizontalSpace = true;
-        m_checkJobRun.setLayoutData(gridData);
-        m_checkJobRun.setText(Messages.getString("run") + " : ");
-        m_checkJobRun.addSelectionListener(new SelectionAdapter() {
-            public void widgetSelected(SelectionEvent e) {
-            	m_jobRun.setEnabled(m_checkJobRun.getSelection());
-            }
-        });
-		
-		// ジョブ実行グループ
-        Group groupRunJob = new Group(groupNotifyAttribute, SWT.NONE);
-        layout = new GridLayout(1, true);
-        layout.marginWidth = 5;
-        layout.marginHeight = 5;
-        layout.numColumns = 1;
-        groupRunJob.setLayout(layout);
-        gridData = new GridData();
-        gridData.horizontalSpan = 15;
-        gridData.horizontalAlignment = GridData.FILL;
-        gridData.grabExcessHorizontalSpace = true;
-        groupRunJob.setLayoutData(gridData);
-        
-        // 実行（実行，ジョブID，通知抑制と連動，呼出失敗時）
-		this.m_jobRun = new TruthRunJobComposite(
-				groupRunJob, 
-				SWT.NONE, 
-				Messages.getString("OK"),
-        		Messages.getString("NG"));
-		gridData = new GridData();
-		gridData.horizontalSpan = 1;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		m_jobRun.setLayoutData(gridData);
-		
+
         /*
          * 有効／無効
          */
@@ -483,21 +437,16 @@ public class AgentCreateDialog extends CommonDialog {
         // ノード単位の結果判定の定義
         m_truthValueInfo.setInputData(monitor);
     	
-        // 通知情報の属性
-        if (monitor.getNotifyId() != null) {
-        	this.notifyInfo.setText(monitor.getNotifyId());
-        }
+        //通知情報の設定
+        if(monitor.getNotifyId() != null)
+        this.notifyInfo.setNotify(monitor.getNotifyId());
+        
+        
+        //アプリケーション
         if (monitor.getApplication() != null) {
         	this.notifyInfo.setApplication(monitor.getApplication());
         }
         
-        // ジョブ実行
-        m_checkJobRun.setSelection(YesNoConstant.typeToBoolean(monitor.getJobRun()));
-        
-        // 各重要度のジョブ実行
-        m_jobRun.setInputData(monitor);
-        m_jobRun.setEnabled(YesNoConstant.typeToBoolean(monitor.getJobRun()));
-        
         // 有効／無効
         if (monitor.getValid() == ValidConstant.TYPE_VALID) {
             this.confirmValid.setSelection(true);
@@ -512,7 +461,7 @@ public class AgentCreateDialog extends CommonDialog {
     protected MonitorInfo createInputData() {
     	MonitorInfo info = new MonitorInfo();
 
-    	info.setMonitorTypeId(MonitorConstant.STRING_AGENT);
+    	info.setMonitorTypeId(HinemosModuleConstant.MONITOR_AGENT);
     	info.setMonitorType(MonitorTypeConstant.TYPE_TRUTH);
     	
     	// 監視基本情報
@@ -528,7 +477,7 @@ public class AgentCreateDialog extends CommonDialog {
         }
         
         MonitorAgentInfo agentInfo = new MonitorAgentInfo();
-		agentInfo.setMonitorTypeId(MonitorConstant.STRING_AGENT);
+		agentInfo.setMonitorTypeId(HinemosModuleConstant.MONITOR_AGENT);
         agentInfo.setMonitorId(info.getMonitorId());
     	if (!this.m_checkJobAgent.getSelection() && !this.m_checkLogAgent.getSelection()) {
     		this.setValidateResult(Messages.getString("message.hinemos.1"),Messages.getString("message.agent.8"));
@@ -550,35 +499,23 @@ public class AgentCreateDialog extends CommonDialog {
         	return null;
         }
         
-        // 通知情報の属性
-        if (this.notifyInfo.getText() != null
-                && !"".equals((this.notifyInfo.getText()).trim())) {
-        	info.setNotifyId(notifyInfo.getText());
-        }
-//        else{
-//        	this.setValidateResult(Messages.getString("message.hinemos.1"),Messages.getString("message.monitor.9"));
-//            return null;
-//        }
-        if (this.notifyInfo.getApplication() != null
-                && !"".equals((this.notifyInfo.getApplication()).trim())) {
-        	info.setApplication(notifyInfo.getApplication());
-        }
-        else{
-        	if (this.notifyInfo.getText() != null
-                    && !"".equals((this.notifyInfo.getText()).trim())) {
-        		this.setValidateResult(Messages.getString("message.hinemos.1"),Messages.getString("message.monitor.10"));
-                return null;	
-        	}
-        }
         
-        // ジョブ実行
-        info.setJobRun(YesNoConstant.booleanToType(m_checkJobRun.getSelection()));
-        
-        // 各重要度のジョブ実行
-        validateResult = m_jobRun.createInputData(info);
-        if(validateResult != null){
-        	return null;
-        }
+        // 通知関連情報とアプリケーションの設定
+		// 通知グループIDの設定
+		info.setNotifyGroupId(NotifyRelationInfo.createNotifyGroupId(HinemosModuleConstant.MONITOR_AGENT, agentInfo.getMonitorId()));
+		validateResult = notifyInfo.createInputData(info);
+		if (validateResult != null) {
+			if(validateResult.getID() == null){	// 通知ID警告用出力
+				if(!displayQuestion(validateResult)){
+					validateResult = null;
+					return null;
+				}
+			}
+			else{	// アプリケーション未入力チェック
+				return null;
+			}
+		}  
+      
         
         // 有効/無効
         if (this.confirmValid.getSelection()) {
