@@ -35,7 +35,7 @@ import com.clustercontrol.util.Messages;
 /**
  * ログ転送スレッドクラス<BR>
  * 
- * @version 2.1.0
+ * @version 3.0.0
  * @since 2.1.0
  */
 public class TransferLogThread extends Thread {
@@ -43,6 +43,8 @@ public class TransferLogThread extends Thread {
 	private final static String UNCHANGED_STATS_PERIOD = "unchanged.stats.period";
 
 	private final static String FILE_MAX_SIZE = "file.max.size";
+	
+	private final static String LOG_ENCODING = "log.file.encoding";
 
 	public static final String MESSAGE_ID_INFO = "001";
 
@@ -79,7 +81,10 @@ public class TransferLogThread extends Thread {
 
 	// ロガー
 	static Log log = LogFactory.getLog(TransferLogThread.class);
-
+	
+	// ログファイルのエンコーディング
+	private String m_logEncoding = "UTF-8";
+	
 	/**
 	 * コンストラクタ
 	 * 
@@ -116,6 +121,14 @@ public class TransferLogThread extends Thread {
 			log.error("TransferLogManager() : " + FILE_MAX_SIZE, e);
 		}
 
+		// ログファイルのエンコーディングを設定
+		m_logEncoding =  props.getProperty(LOG_ENCODING);
+		
+		// プロパティファイルに設定がない場合
+		if(m_logEncoding == null){
+			m_logEncoding = System.getProperty("file.encoding"); 
+		}
+		
 		m_syslog = new LoggerSyslog(props);
 	}
 
@@ -130,6 +143,10 @@ public class TransferLogThread extends Thread {
 	 */
 	@Override
 	public void run() {
+		log.info("monitor start.  logfile : " + m_filePath 
+				+ "  interval : " + m_runInterval + "s"
+				+ "  logfile encoding : " + m_logEncoding
+				+ "  syslog encoding : " + System.getProperty("file.encoding"));
 
 		long filesize = 0;
 		long tmp_filesize = 0;
@@ -290,9 +307,11 @@ public class TransferLogThread extends Thread {
 						// //
 
 						try {
+//							sb.append(new String(appendedBuf, 0,
+//									appendedBuf.length, System
+//											.getProperty("file.encoding")));
 							sb.append(new String(appendedBuf, 0,
-									appendedBuf.length, System
-											.getProperty("file.encoding")));
+									appendedBuf.length, m_logEncoding));							
 						} catch (UnsupportedEncodingException e) {
 							log.error("run() : " + m_filePath + " "
 									+ e.getMessage());
@@ -338,11 +357,11 @@ public class TransferLogThread extends Thread {
 			} catch (IOException e) {
 				log.error("run() : " + e.getMessage());
 				Object[] args = { this.m_filePath };
-				sendMessage(PriorityConstant.TYPE_WARNING, Messages
-						.getString("message.log.agent.4"), MESSAGE_ID_WARNING,
-						Messages.getString("message.log.agent.4"), Messages
-								.getString("message.log.agent.1", args)
-								+ "\n" + e.getMessage());
+				sendMessage(PriorityConstant.TYPE_WARNING, 
+						Messages.getString("log.agent"), 
+						MESSAGE_ID_WARNING,
+						Messages.getString("message.log.agent.4"), 
+						Messages.getString("message.log.agent.1", args) + "\n" + e.getMessage());
 
 				// エラーが発生したのでファイルクローズし再オープン
 
@@ -427,13 +446,12 @@ public class TransferLogThread extends Thread {
 					// ファイルサイズが大きい場合、監視管理へ通知
 					Object[] args1 = { this.m_filePath };
 					Object[] args2 = { filesize };
-					sendMessage(PriorityConstant.TYPE_INFO, Messages
-							.getString("message.log.agent.3"), MESSAGE_ID_INFO,
-							Messages.getString("message.log.agent.3"), Messages
-									.getString("message.log.agent.1", args1)
-									+ ", "
-									+ Messages.getString("message.log.agent.5",
-											args2));
+					sendMessage(PriorityConstant.TYPE_INFO, 
+							Messages.getString("log.agent"), 
+							MESSAGE_ID_INFO,
+							Messages.getString("message.log.agent.3"), 
+							Messages.getString("message.log.agent.1", args1) + ", "	
+								+ Messages.getString("message.log.agent.5",args2));
 				}
 
 				// ファイルポインタの設定
@@ -448,10 +466,10 @@ public class TransferLogThread extends Thread {
 					if (this.m_existenceFlg == YesNoConstant.TYPE_YES) {
 						// 最初にファイルをチェックする場合、監視管理へ通知
 						Object[] args = { this.m_filePath };
-						sendMessage(PriorityConstant.TYPE_INFO, Messages
-								.getString("message.log.agent.2"),
-								MESSAGE_ID_INFO, Messages
-										.getString("message.log.agent.2"),
+						sendMessage(PriorityConstant.TYPE_INFO,
+								Messages.getString("log.agent"),
+								MESSAGE_ID_INFO, 
+								Messages.getString("message.log.agent.2"),
 								Messages.getString("message.log.agent.1", args));
 					}
 					err = true;
@@ -461,22 +479,22 @@ public class TransferLogThread extends Thread {
 				if (!err) {
 					// 監視管理へ通知
 					Object[] args = { this.m_filePath };
-					sendMessage(PriorityConstant.TYPE_WARNING, Messages
-							.getString("message.log.agent.4"),
-							MESSAGE_ID_WARNING, Messages
-									.getString("message.log.agent.4"), Messages
-									.getString("message.log.agent.1", args)
-									+ "\n" + e.getMessage());
+					sendMessage(PriorityConstant.TYPE_WARNING, 
+							Messages.getString("log.agent"),
+							MESSAGE_ID_WARNING, 
+							Messages.getString("message.log.agent.4"),
+							Messages.getString("message.log.agent.1", args) + "\n" + e.getMessage());
 					err = true;
 				}
 			} catch (IOException e) {
 				if (!err) {
 					// 監視管理へ通知
 					Object[] args = { this.m_filePath };
-					sendMessage(PriorityConstant.TYPE_INFO, Messages
-							.getString("message.log.agent.4"), MESSAGE_ID_INFO,
-							Messages.getString("message.log.agent.4"), Messages
-									.getString("message.log.agent.1", args));
+					sendMessage(PriorityConstant.TYPE_INFO, 
+							Messages.getString("log.agent"), 
+							MESSAGE_ID_INFO,
+							Messages.getString("message.log.agent.4"), 
+							Messages.getString("message.log.agent.1", args));
 					err = true;
 				}
 
