@@ -37,7 +37,7 @@ public class StringValueListTabelDefine {
 	public static final int DESCRIPTION = 2;
 	
 	/** 通知ID。 */
-	public static final int NOTIFY_ID = 3;
+	public static final int VALID_FLG = 3;
 	
 	/** メッセージID。 */
 	public static final int MESSAGE_ID = 4;
