@@ -585,7 +585,7 @@ public class CollectorBean implements EntityBean {
 					Iterator<CollectorSnmpMstLocal> itr = beans.iterator();
 
 					while(itr.hasNext()){
-						oids.add(itr.next().getTableOid());
+						oids.add(itr.next().getPollingOid());
 					}
 				}
 
