@@ -242,7 +242,7 @@ public class FacilityDAOImpl implements FacilityDAO {
 					
 					//ccFacilitySortValue取得
 					if(attrs.get(FacilityAttributeConstant.SORT_VALUE) != null){
-						ejb.setSnmpVersion((String)attrs.get(FacilityAttributeConstant.SORT_VALUE).get(0));
+						ejb.setSortValue(new Integer((String)attrs.get(FacilityAttributeConstant.SORT_VALUE).get(0)));
 					}
 
 					
