@@ -15,6 +15,7 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.repository.ejb.session;
 
+import java.net.UnknownHostException;
 import java.rmi.RemoteException;
 import java.security.Principal;
 import java.util.ArrayList;
@@ -41,6 +42,8 @@ import com.clustercontrol.repository.bean.FacilityTreeAttributeConstant;
 import com.clustercontrol.repository.bean.NodeListTabelDefine;
 import com.clustercontrol.repository.bean.NodeScopeTabelDefine;
 import com.clustercontrol.repository.bean.ScopeListTableDefine;
+import com.clustercontrol.repository.ejb.entity.FacilityLocal;
+import com.clustercontrol.repository.ejb.entity.FacilityUtil;
 import com.clustercontrol.repository.factory.DeleteFacility;
 import com.clustercontrol.repository.factory.ModifyFacility;
 import com.clustercontrol.repository.factory.NodeFilterProperty;
@@ -578,6 +581,58 @@ public abstract class RepositoryControllerBean implements javax.ejb.SessionBean
 		}
 	}
 	
+	/**
+	 * 
+	 * 監視・ジョブ等の処理を実行する対象となる、ファシリティIDのリストを取得します。
+	 * 引数で指定されたファシリティIDが、ノードかスコープによって、以下のようなリストを取得します。
+	 * 
+	 * ノードの場合
+	 *   引数で指定されたfacilityIdが格納されたArrauList
+	 *   ただし、管理対象（有効/無効フラグが真）の場合のみ
+	 * 
+	 * スコープの場合
+	 *   配下に含まれるノードのファシリティIDが格納されたArrayList
+	 *   ただし、管理対象（有効/無効フラグが真）のみ
+	 * 
+	 * 
+	 * @ejb.interface-method
+	 * 
+	 * @ejb.permission
+     *     role-name="RepositoryRead"
+     *     method-intf="Remote"
+	 *     
+     * @ejb.transaction
+	 *     type="NotSupported"
+	 * 
+	 * @version 3.0.0
+	 * @since 3.0.0
+	 * 
+	 * 
+	 * @param facilityId 処理を実行する対象となるファシリティID
+	 * @return 有効なノードのリスト（有効なノードがひとつも含まれない場合は空のリスト）
+	 * @throws FinderException
+	 * @throws NamingException
+	 */
+	public ArrayList<String> getExecTargetFacilityIdList(String facilityId) throws FinderException, NamingException{
+		ArrayList<String> ret = null;
+		
+		if (this.isNode(facilityId)) {
+			ret = new ArrayList<String>();
+			
+			FacilityLocal facility = FacilityUtil.getLocalHome().findByFacilityId(facilityId);
+			// 対象がノードかつ、有効無効フラグが真なら、facilityIdをArrayListに追加して返す
+			if (facility.getValid()){
+				ret.add(facilityId);
+			}
+			
+		} else {
+			ret = this.getNodeFacilityIdList(facilityId, RepositoryControllerBean.ALL);
+		}
+		
+		return ret;
+	}
+	
+	
 	/**
      * ノードのファシリティIDリストを取得します。<BR>
 	 * 
@@ -608,7 +663,7 @@ public abstract class RepositoryControllerBean implements javax.ejb.SessionBean
 		try {
 			//ファシリティツリーを取得
 			SelectFacility select = new SelectFacility();
-			ArrayList list = select.getNodeFacilityIdList(parentFacilityId, level, false);
+			ArrayList list = select.getNodeFacilityIdList(parentFacilityId, level, false, new Boolean(true));
 			return list;
 		} catch (FinderException e) {
 			m_log.debug("RepositoryControllerBean.getNodeFacilityIdList() -> " + e.getMessage());
@@ -644,12 +699,12 @@ public abstract class RepositoryControllerBean implements javax.ejb.SessionBean
 	 * @throws NamingException
 	 * @throws FinderException
 	 */
-	public ArrayList getNodeFacilityIdList(String parentFacilityId, int level, boolean sort) throws FinderException, NamingException {
+	public ArrayList getNodeFacilityIdList(String parentFacilityId, int level, boolean sort, Boolean valid) throws FinderException, NamingException {
 		
 		try {
 			//ファシリティツリーを取得
 			SelectFacility select = new SelectFacility();
-			ArrayList list = select.getNodeFacilityIdList(parentFacilityId, level, sort);
+			ArrayList list = select.getNodeFacilityIdList(parentFacilityId, level, sort, valid);
 			return list;
 		} catch (FinderException e) {
 			m_log.debug("RepositoryControllerBean.getNodeFacilityIdList() -> " + e.getMessage());
@@ -967,19 +1022,21 @@ public abstract class RepositoryControllerBean implements javax.ejb.SessionBean
 	 * @throws NamingException
 	 * @throws CreateException
 	 */
-	public void addNode(Property property) throws NamingException, CreateException {
-		Principal pri = m_context.getCallerPrincipal();
+	public void addNode(Property property) throws NamingException, CreateException, FinderException {
+ 		Principal pri = m_context.getCallerPrincipal();
 			
 		ModifyFacility modify = new ModifyFacility();
 		modify.addNode(property, pri.getName()); //pri.getName()はメソッドの実行ユーザ
 		
-		
 		//ノード追加されると必ず"登録済みノード"スコープに登録される
 		//ファシリティID取得
 		ArrayList values = PropertyUtil.getPropertyValue(property, NodeProperty.FACILITY_ID);
 		String[] facilityId = new String[1];
 		facilityId[0] = (String)values.get(0);
-		assignNodeScope(FacilityTreeAttributeConstant.REGISTEREFD_SCOPE,facilityId);
+		
+		//登録済みノードとしてスコープに割り当てる
+		modify.assignNodeScope(FacilityTreeAttributeConstant.REGISTEREFD_SCOPE, facilityId);
+
 	}
 	
 	/**
@@ -1009,6 +1066,10 @@ public abstract class RepositoryControllerBean implements javax.ejb.SessionBean
 			
 			ModifyFacility modify = new ModifyFacility();
 			modify.modifyNode(property, pri.getName());
+			
+			//facilitytreeとして登録されている、有効/無効フラグを変更する
+			modify.modifyFacilityTreeValid(property);
+			
 		} catch (NamingException e) {
 			throw e;
 		} catch (FinderException e) {
@@ -1151,7 +1212,7 @@ public abstract class RepositoryControllerBean implements javax.ejb.SessionBean
 	 * @throws NamingException
 	 * @throws CreateException
 	 */
-	public void assignNodeScope(String parentFacilityId, String[] facilityIds) throws NamingException, CreateException {
+	public void assignNodeScope(String parentFacilityId, String[] facilityIds) throws NamingException, CreateException, FinderException {
 		try {
 			ModifyFacility modify = new ModifyFacility();
 			modify.assignNodeScope(parentFacilityId, facilityIds);
@@ -1159,6 +1220,8 @@ public abstract class RepositoryControllerBean implements javax.ejb.SessionBean
 			throw e;
 		} catch (CreateException e) {
 			throw e;
+		} catch (FinderException e) {
+			throw e;
 		}
 	}
 	
@@ -1455,7 +1518,7 @@ public abstract class RepositoryControllerBean implements javax.ejb.SessionBean
      * @param locale クライアントのロケール
      * @return ノード情報のproperty
      */
-    public Property  getNodePropertyBySNMP(Hashtable pollingData,int mode, Locale locale){
+    public Property  getNodePropertyBySNMP(Hashtable pollingData,int mode, Locale locale) throws FinderException, NamingException, UnknownHostException {
              return  SearchNodeBySNMP.searchNode(pollingData,mode,locale);
             
     }
