@@ -18,8 +18,6 @@ package com.clustercontrol.snmp.dialog;
 import java.util.ArrayList;
 
 import org.eclipse.swt.SWT;
-import org.eclipse.swt.events.SelectionAdapter;
-import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.graphics.Point;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
@@ -34,11 +32,10 @@ import org.eclipse.swt.widgets.Text;
 
 import com.clustercontrol.bean.ConvertValueConstant;
 import com.clustercontrol.bean.DataRangeConstant;
+import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.MonitorBlockConstant;
-import com.clustercontrol.bean.MonitorConstant;
 import com.clustercontrol.bean.SnmpVersionConstant;
 import com.clustercontrol.bean.ValidConstant;
-import com.clustercontrol.bean.YesNoConstant;
 import com.clustercontrol.composite.PositiveNumberVerifyListener;
 import com.clustercontrol.composite.StringVerifyListener;
 import com.clustercontrol.dialog.CommonDialog;
@@ -49,9 +46,9 @@ import com.clustercontrol.monitor.run.bean.MonitorTypeConstant;
 import com.clustercontrol.monitor.run.composite.MonitorBasicScopeComposite;
 import com.clustercontrol.monitor.run.composite.MonitorBlockComposite;
 import com.clustercontrol.monitor.run.composite.MonitorRuleComposite;
-import com.clustercontrol.monitor.run.composite.NumericRunJobComposite;
 import com.clustercontrol.monitor.run.composite.NumericValueInfoComposite;
 import com.clustercontrol.monitor.run.composite.StringValueInfoComposite;
+import com.clustercontrol.notify.bean.NotifyRelationInfo;
 import com.clustercontrol.notify.composite.NotifyInfoComposite;
 import com.clustercontrol.snmp.action.AddSnmp;
 import com.clustercontrol.snmp.action.GetSnmp;
@@ -63,7 +60,7 @@ import com.clustercontrol.util.Messages;
 /**
  * SNMP監視作成・変更ダイアログクラス<BR>
  * 
- * @version 2.2.0
+ * @version 3.0.0
  * @since 2.0.0
  */
 public class SnmpCreateDialog extends CommonDialog {
@@ -118,8 +115,6 @@ public class SnmpCreateDialog extends CommonDialog {
     /** ジョブ実行 */
     private Button m_checkJobRun = null;
     
-    /** ジョブ実行情報 */
-    private NumericRunJobComposite m_jobRun = null;
     
     /** この設定を有効にする */
     private Button confirmValid = null;
@@ -335,7 +330,7 @@ public class SnmpCreateDialog extends CommonDialog {
         gridData.grabExcessHorizontalSpace = true;
         this.m_textOid.setLayoutData(gridData);
         this.m_textOid.addVerifyListener(
-        		new StringVerifyListener(DataRangeConstant.VARCHAR_64));
+        		new StringVerifyListener(DataRangeConstant.VARCHAR_1024));
         // 空白
         label = new Label(groupCheckRule, SWT.NONE);
         gridData = new GridData();
@@ -522,41 +517,7 @@ public class SnmpCreateDialog extends CommonDialog {
 		
 		// 数値監視の場合     
 		if(m_monitorType == MonitorTypeConstant.TYPE_NUMERIC){
-			
-			// ジョブ実行
-	        this.m_checkJobRun = new Button(groupNotifyAttribute, SWT.CHECK);
-	        gridData = new GridData();
-	        gridData.horizontalSpan = 1;
-	        gridData.horizontalAlignment = GridData.FILL;
-	        gridData.grabExcessHorizontalSpace = true;
-	        m_checkJobRun.setLayoutData(gridData);
-	        m_checkJobRun.setText(Messages.getString("run") + " : ");
-	        m_checkJobRun.addSelectionListener(new SelectionAdapter() {
-	            public void widgetSelected(SelectionEvent e) {
-	            	m_jobRun.setEnabled(m_checkJobRun.getSelection());
-	            }
-	        });
-			
-			// ジョブ実行グループ
-	        Group groupRunJob = new Group(groupNotifyAttribute, SWT.NONE);
-	        layout = new GridLayout(1, true);
-	        layout.marginWidth = 5;
-	        layout.marginHeight = 5;
-	        layout.numColumns = 1;
-	        groupRunJob.setLayout(layout);
-	        gridData = new GridData();
-	        gridData.horizontalSpan = 15;
-	        gridData.horizontalAlignment = GridData.FILL;
-	        gridData.grabExcessHorizontalSpace = true;
-	        groupRunJob.setLayoutData(gridData);
-	        
-	        // 実行（実行，ジョブID，通知抑制と連動，呼出失敗時）
-			this.m_jobRun = new NumericRunJobComposite(groupRunJob, SWT.NONE);
-			gridData = new GridData();
-			gridData.horizontalSpan = 1;
-			gridData.horizontalAlignment = GridData.FILL;
-			gridData.grabExcessHorizontalSpace = true;
-			m_jobRun.setLayoutData(gridData);
+
 		}
 		// 文字列監視の場合
 		else if(m_monitorType == MonitorTypeConstant.TYPE_STRING){
@@ -695,13 +656,18 @@ public class SnmpCreateDialog extends CommonDialog {
     		}
         }
         
-        // 通知情報の属性
-        if (monitor.getNotifyId() != null) {
-        	this.m_notifyInfo.setText(monitor.getNotifyId());
-        }
+    	
+        //通知情報の設定
+        if(monitor.getNotifyId() != null)
+        this.m_notifyInfo.setNotify(monitor.getNotifyId());
+        
+        
+        
         if (monitor.getApplication() != null) {
         	this.m_notifyInfo.setApplication(monitor.getApplication());
         }
+     
+        
         
         // 数値監視の場合     
 		if(m_monitorType == MonitorTypeConstant.TYPE_NUMERIC){
@@ -709,12 +675,6 @@ public class SnmpCreateDialog extends CommonDialog {
 			// ノード単位の重要度の定義
 	        m_numericValueInfo.setInputData(monitor);
 	    	
-	        // ジョブ実行
-	        m_checkJobRun.setSelection(YesNoConstant.typeToBoolean(monitor.getJobRun()));
-	        
-	        // 各重要度のジョブ実行
-	        m_jobRun.setInputData(monitor);
-	        m_jobRun.setEnabled(YesNoConstant.typeToBoolean(monitor.getJobRun()));
 		}
 		// 文字列監視の場合
 		else if(m_monitorType == MonitorTypeConstant.TYPE_STRING){
@@ -737,7 +697,7 @@ public class SnmpCreateDialog extends CommonDialog {
     protected MonitorInfo createInputData() {
     	MonitorInfo info = new MonitorInfo();
 
-    	info.setMonitorTypeId(MonitorConstant.STRING_SNMP);
+    	info.setMonitorTypeId(HinemosModuleConstant.MONITOR_SNMP);
     	info.setMonitorType(m_monitorType);
     	
     	// 監視基本情報
@@ -767,7 +727,7 @@ public class SnmpCreateDialog extends CommonDialog {
         
         // 監視条件 SNMP監視情報
         MonitorSnmpInfo snmpInfo = new MonitorSnmpInfo();
-        snmpInfo.setMonitorTypeId(MonitorConstant.STRING_SNMP);
+        snmpInfo.setMonitorTypeId(HinemosModuleConstant.MONITOR_SNMP);
         snmpInfo.setMonitorId(info.getMonitorId());
         
         if (this.m_textCommunityName.getText() != null
@@ -822,26 +782,22 @@ public class SnmpCreateDialog extends CommonDialog {
 		}
         info.setCheckInfo((MonitorCheckInfo)snmpInfo);
         
-        // 通知情報の属性
-        if (this.m_notifyInfo.getText() != null
-                && !"".equals((this.m_notifyInfo.getText()).trim())) {
-        	info.setNotifyId(m_notifyInfo.getText());
-        }
-//        else{
-//        	this.setValidateResult(Messages.getString("message.hinemos.1"),Messages.getString("message.monitor.9"));
-//            return null;
-//        }
-        if (this.m_notifyInfo.getApplication() != null
-                && !"".equals((this.m_notifyInfo.getApplication()).trim())) {
-        	info.setApplication(m_notifyInfo.getApplication());
-        }
-        else{
-        	if (this.m_notifyInfo.getText() != null
-                    && !"".equals((this.m_notifyInfo.getText()).trim())) {
-            	this.setValidateResult(Messages.getString("message.hinemos.1"),Messages.getString("message.monitor.10"));
-                return null;
-            }
-        }
+        
+        // 通知関連情報とアプリケーションの設定
+		// 通知グループIDの設定
+		info.setNotifyGroupId(NotifyRelationInfo.createNotifyGroupId(HinemosModuleConstant.MONITOR_SNMP, info.getMonitorId()));
+		validateResult = m_notifyInfo.createInputData(info);
+		if (validateResult != null) {
+			if(validateResult.getID() == null){	// 通知ID警告用出力
+				if(!displayQuestion(validateResult)){
+					validateResult = null;
+					return null;
+				}
+			}
+			else{	// アプリケーション未入力チェック
+				return null;
+			}
+		}  
         
         //　数値監視の場合     
 		if(m_monitorType == MonitorTypeConstant.TYPE_NUMERIC){
@@ -851,14 +807,6 @@ public class SnmpCreateDialog extends CommonDialog {
 	        	return null;
 	        }
 	        
-	        // ジョブ実行
-	        info.setJobRun(YesNoConstant.booleanToType(m_checkJobRun.getSelection()));
-	        
-	        // 各重要度のジョブ実行
-	        validateResult = m_jobRun.createInputData(info);
-	        if(validateResult != null){
-	        	return null;
-	        }
 		}
 		// 文字列監視の場合
 		else if(m_monitorType == MonitorTypeConstant.TYPE_STRING){
@@ -878,8 +826,6 @@ public class SnmpCreateDialog extends CommonDialog {
 	            }
 	        }
 	        
-	        // ジョブ実行
-	        info.setJobRun(YesNoConstant.TYPE_YES);
 		}
         
         // 有効/無効
