@@ -26,5 +26,5 @@ package com.clustercontrol.snmptrap.bean;
  */
 public class TopicConstant {
 	/** SNMPTRAP監視更新用トピック */
-	public static final String TOPIC_NAME_UPDATE = "topic/clustercontrol/SnmpTrap/update";
+	public static final String TOPIC_NAME_UPDATE = "topic/clustercontrolSnmpTrapUpdate";
 }
