@@ -25,5 +25,5 @@ package com.clustercontrol.syslogng.bean;
 public class TopicConstant {
 	
     /** リポジトリ更新用トピック名。 */
-    public static final String TOPIC_NAME_EXECUTE = "topic/clustercontrol/Repository/update";
+    public static final String TOPIC_NAME_EXECUTE = "topic/clustercontrolRepositoryUpdate";
 }
